==> haskell-servant-swagger-1.1.10-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-swagger
version:              1.1.10
visibility:           public
id:                   servant-swagger-1.1.10-D6EgewH0xbPODkLEBP7A
key:                  servant-swagger-1.1.10-D6EgewH0xbPODkLEBP7A
license:              BSD-3-Clause
copyright:            (c) 2015-2018, Servant contributors
maintainer:           nickolay.kudasov@gmail.com
author:               David Johnson, Nickolay Kudasov
homepage:             https://github.com/haskell-servant/servant-swagger
synopsis:
    Generate a Swagger/OpenAPI/OAS 2.0 specification for your servant API.

description:
    Swagger is a project used to describe and document RESTful APIs. The core of the
    project is the [OpenAPI Specification (OAS)](https://swagger.io/docs/specification/about/).
    This library implements v2.0 of the spec. Unlike Servant it is language-agnostic and thus is
    quite popular among developers in different languages. It has also existed for a longer time
    and has more helpful tooling.

    This package provides means to generate a Swagger/OAS specification for a Servant API
    and also to partially test whether an API conforms with its specification.

    Generated Swagger specification then can be used for many things such as

    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);

    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);

    * and [many others](http://swagger.io/open-source-integrations/).

category:             Web, Servant, Swagger
abi:                  ea88864f71aa3a202f9f4a4256aa87a8
exposed:              True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel

import-dirs:          /usr/lib/ghc-8.10.4/site-local/servant-swagger-1.1.10
library-dirs:         /usr/lib/ghc-8.10.4/site-local/servant-swagger-1.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/servant-swagger-1.1.10
hs-libraries:         HSservant-swagger-1.1.10-D6EgewH0xbPODkLEBP7A
depends:
    QuickCheck-2.14.2-5khM4PuTHWuGr7R0xX0xET
    aeson-1.5.5.1-6NWVvXrflAc8ojSfaztJWW
    aeson-pretty-0.8.8-DYEfNrt2I5c89ZlNaBElWq base-4.14.1.0
    base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3 bytestring-0.10.12.0
    hspec-2.7.7-3tBaVsCoGjt8nFL0pOXhUi
    http-media-0.8.0.0-7lIIFx2QsZe7oSN9JhQEPj
    insert-ordered-containers-0.2.3.1-FL1aeZUy1euKRgYXr22n8Y
    lens-4.19.2-KNa10bCNgvv3bvnt8aA7wR
    servant-0.18.2-7fCcezY4jPLJZas3E4CIXx
    singleton-bool-0.1.5-HROmJ2x3IGbHtluHkmYgNW
    swagger2-2.6-89JcN20nsT9UYot3JaAHp text-1.2.4.1
    unordered-containers-0.2.13.0-48OepUjtvPcKuQlUwC19ed

haddock-interfaces:
    /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock

haddock-html:         /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-swagger-1.1.10-118-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-swagger
version:              1.1.10
visibility:           public
id:                   servant-swagger-1.1.10-2BdIZZcP7hmCnUSZxVcP6e
key:                  servant-swagger-1.1.10-2BdIZZcP7hmCnUSZxVcP6e
license:              BSD-3-Clause
copyright:            (c) 2015-2018, Servant contributors
maintainer:           nickolay.kudasov@gmail.com
author:               David Johnson, Nickolay Kudasov
homepage:             https://github.com/haskell-servant/servant-swagger
synopsis:
    Generate a Swagger/OpenAPI/OAS 2.0 specification for your servant API.

description:
    Swagger is a project used to describe and document RESTful APIs. The core of the
    project is the [OpenAPI Specification (OAS)](https://swagger.io/docs/specification/about/).
    This library implements v2.0 of the spec. Unlike Servant it is language-agnostic and thus is
    quite popular among developers in different languages. It has also existed for a longer time
    and has more helpful tooling.

    This package provides means to generate a Swagger/OAS specification for a Servant API
    and also to partially test whether an API conforms with its specification.

    Generated Swagger specification then can be used for many things such as

    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);

    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);

    * and [many others](http://swagger.io/open-source-integrations/).

category:             Web, Servant, Swagger
abi:                  e4d6956b46f954867afe6f6bf567d499
exposed:              True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel

import-dirs:          /usr/lib/ghc-8.10.4/site-local/servant-swagger-1.1.10
library-dirs:         /usr/lib/ghc-8.10.4/site-local/servant-swagger-1.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/servant-swagger-1.1.10
hs-libraries:         HSservant-swagger-1.1.10-2BdIZZcP7hmCnUSZxVcP6e
depends:
    QuickCheck-2.14.2-5kAGyNKLRrIFYmj488qD59
    aeson-1.5.6.0-Hdtf8YdIqJe4Gv7Q5rRICM
    aeson-pretty-0.8.8-8LRat5C2Plh7nWR6iqSi1g base-4.14.1.0
    base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3 bytestring-0.10.12.0
    hspec-2.7.7-EgKTGam3cJ5JADnXd1YGhn
    http-media-0.8.0.0-HTg5IanTEO696t4uyNmQh
    insert-ordered-containers-0.2.3.1-J5nZ2XcRBA75ozRfdISM4D
    lens-4.19.2-C1LTFIThy7JLUdCtYMuxic
    servant-0.18.2-2UviGBrbQEI5WD2YpEchTy
    singleton-bool-0.1.5-AMAzfSfuY3w2SeCcEcyHjl
    swagger2-2.6-FSuwkthnOd7IdJacJkV9g6 text-1.2.4.1
    unordered-containers-0.2.13.0-3nLuuqaKwKc70HW85Q2c85

haddock-interfaces:
    /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock

haddock-html:         /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
